@@ -26,6 +26,7 @@
 #include <QHostAddress>
 #include <QList>
 #include <QString>
+#include <QStringList>
 
 #define ENDPOINTMAP_MAP_DIRECTORY "/etc/drouter.d/maps"
 #define ENDPOINTMAP_MAP_FILTER QString("*.map")
@@ -68,17 +69,21 @@ class EndPointMap
   void setHostAddress(Type type,int n,const QString &addr);
   int slot(Type type,int n) const;
   void setSlot(Type type,int n,int slot);
+  QString name(Type type,int n,const QString &orig_name=QString()) const;
+  void setName(Type type,int n,const QString &str);
   int endPoint(Type type,const QHostAddress &hostaddr,int slot) const;
   int endPoint(Type type,const QString &hostaddr,int slot) const;
-  void insert(Type type,int n,const QHostAddress &host_addr,int slot);
-  void insert(Type type,int n,const QString &host_addr,int slot);
+  void insert(Type type,int n,const QHostAddress &host_addr,int slot,
+	      const QString &name=QString());
+  void insert(Type type,int n,const QString &host_addr,int slot,
+	      const QString &name=QString());
   void erase(Type type,int n);
   int snapshotQuantity() const;
   Snapshot *snapshot(int n) const;
   Snapshot *snapshot(const QString &name);
   bool load(const QString &filename,QStringList *unused_lines=NULL);
-  bool save(const QString &filename) const;
-  void save(FILE *f) const;
+  bool save(const QString &filename,bool incl_names) const;
+  void save(FILE *f,bool incl_names) const;
   static bool loadSet(QMap<int,EndPointMap *> *maps,QStringList *msgs);
   static QString routerTypeString(RouterType type);
   static QString typeString(Type type);
@@ -89,6 +94,7 @@ class EndPointMap
   RouterType map_router_type;
   QList<QHostAddress> map_host_addresses[EndPointMap::LastType];
   QList<int> map_slots[EndPointMap::LastType];
+  QStringList map_names[EndPointMap::LastType];
   QList<Snapshot *> map_snapshots;
 };
 
