@@ -22,10 +22,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <syslog.h>
+#include <unistd.h>
 
 #include <QCoreApplication>
-#include <QDir>
-#include <QHostAddress>
 
 #include <sy/sycmdswitch.h>
 
@@ -34,32 +33,33 @@
 #endif  // LIBSYSTEMD
 
 #include "drouterd.h"
-#include "protocolfactory.h"
 
 bool global_reload=false;
-
-void SigHandler(int signo)
-{
-  switch(signo) {
-  case SIGHUP:
-    global_reload=true;
-    break;
-  }
-}
-
+bool global_exiting=false;
 
 MainObject::MainObject(QObject *parent)
   : QObject(parent)
 {
-  bool no_scripts=false;
-  int socks[2]={-1,-1};
+  main_no_scripts=false;
+  main_protocol_socks[0]=-1;
+  main_protocol_socks[1]=-1;
   int n;
+  bool no_protocols=false;
   QString err_msg;
+  int log_options=0;
   SyCmdSwitch *cmd=
     new SyCmdSwitch(qApp->argc(),qApp->argv(),"drouterd",VERSION,DROUTERD_USAGE);
   for(unsigned i=0;i<(cmd->keys());i++) {
+    if(cmd->key(i)=="-d") {
+      log_options=log_options|LOG_PERROR;;
+      cmd->setProcessed(i,true);
+    }
     if(cmd->key(i)=="--no-scripts") {
-      no_scripts=true;
+      main_no_scripts=true;
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--no-protocols") {
+      no_protocols=true;
       cmd->setProcessed(i,true);
     }
     if(!cmd->processed(i)) {
@@ -71,12 +71,8 @@ MainObject::MainObject(QObject *parent)
   //
   // Open Syslog
   //
-  openlog("drouterd",LOG_PERROR,LOG_DAEMON);
+  openlog("drouterd",log_options,LOG_DAEMON);
 
-  //
-  // DRouter
-  //
-  main_drouter=new DRouter(this);
 
 #ifdef LIBSYSTEMD
   //
@@ -85,78 +81,83 @@ MainObject::MainObject(QObject *parent)
   n=sd_listen_fds(0);
   if(n>0) {
     if(n==2) {
-      socks[0]=SD_LISTEN_FDS_START+0;
-      socks[1]=SD_LISTEN_FDS_START+1;
+      main_protocol_socks[0]=SD_LISTEN_FDS_START+0;
+      main_protocol_socks[1]=SD_LISTEN_FDS_START+1;
     }
     else {
-      fprintf(stderr,"drouterd: error receiving sockets from SystemD\n");
+      syslog(LOG_ERR,"error receiving sockets from Systemd, aborting");
       exit(1);
     }
   }
 #endif  // LIBSYSTEMD
 
-  //
-  // Protocols
-  //
-  main_protocols.
-    push_back(ProtocolFactory(main_drouter,Protocol::ProtocolD,socks[0],this));
-  main_protocols.
-    push_back(ProtocolFactory(main_drouter,Protocol::ProtocolSa,socks[1],this));
-
   //
   // State Scripts
   //
-  main_script_timer=new QTimer(this);
-  main_script_timer->setSingleShot(true);
-  connect(main_script_timer,SIGNAL(timeout()),this,SLOT(scriptsData()));
-  if(!no_scripts) {
-    main_script_timer->start(30000);
+  main_script_engine=new ScriptEngine();
+
+  main_scripts_timer=new QTimer(this);
+  main_scripts_timer->setSingleShot(true);
+  connect(main_scripts_timer,SIGNAL(timeout()),this,SLOT(scriptsData()));
+
+  //
+  // Start Router Process
+  //
+  main_drouter=new DRouter(main_protocol_socks,this);
+  if(!main_drouter->start(&err_msg)) {
+    syslog(LOG_ERR,"core router startup error: %s, aborting",
+	   (const char *)err_msg.toUtf8());
+    exit(1);
   }
 
   //
-  // Set Signals
+  // Protocol Start Timer
   //
-  main_signal_timer=new QTimer(this);
-  connect(main_signal_timer,SIGNAL(timeout()),this,SLOT(signalData()));
-  main_signal_timer->start(500);
-  signal(SIGHUP,SigHandler);
+  main_protocol_timer=new QTimer(this);
+  main_protocol_timer->setSingleShot(true);
+  connect(main_protocol_timer,SIGNAL(timeout()),this,SLOT(protocolData()));
+  if(!no_protocols) {
+    main_protocol_timer->start(DROUTERD_PROTOCOL_START_INTERVAL);
+  }
+}
+
+
+void MainObject::protocolData()
+{
+  pid_t pid=0;
+
+  if((pid=fork())==0) {
+    if(main_protocol_socks[0]<0) {
+      execl("/usr/sbin/dprotod","dprotod","--protocol-d",(char *)NULL);
+    }
+    else {
+      execl("/usr/sbin/dprotod","dprotod","--protocol-d","--systemd",
+	    (char *)NULL);
+    }
+  }
+  main_protocol_pids.push_back(pid);
+  syslog(LOG_INFO,"started Protocol D protocol");
+
+  if((pid=fork())==0) {
+    if(main_protocol_socks[1]<0) {
+      execl("/usr/sbin/dprotod","dprotod","--protocol-sa",(char *)NULL);
+    }
+    else {
+      execl("/usr/sbin/dprotod","dprotod","--protocol-sa","--systemd",
+	    (char *)NULL);
+    }
+  }
+  main_protocol_pids.push_back(pid);
+  syslog(LOG_INFO,"started Software Authority protocol");
+  if(!main_no_scripts) {
+    main_scripts_timer->start(5000);
+  }
 }
 
 
 void MainObject::scriptsData()
 {
-  for(int i=0;i<main_scripts.size();i++) {
-    delete main_scripts.at(i);
-  }
-  main_scripts.clear();
-
-  QDir dir(DROUTERD_SCRIPTS_DIRECTORY);
-  QStringList filters;
-  filters.push_back(DROUTERD_SCRIPTS_FILTER);
-  QStringList scripts=dir.entryList(filters,QDir::Files|QDir::Executable);
-
-  for(int i=0;i<scripts.size();i++) {
-    main_scripts.push_back(new ScriptHost(DROUTERD_SCRIPTS_DIRECTORY+"/"+
-					  scripts.at(i),this));
-    main_scripts.back()->start();
-    //    printf("script[%d]: %s\n",i,(const char *)scripts.at(i).toUtf8());
-  }
-}
-
-
-void MainObject::signalData()
-{
-  if(global_reload) {
-    for(int i=0;i<main_scripts.size();i++) {
-      main_scripts.at(i)->terminate();
-    }
-    for(int i=0;i<main_protocols.size();i++) {
-      main_protocols.at(i)->reload();
-    }
-    syslog(LOG_INFO,"reloaded configuration");
-    main_script_timer->start(30000);
-    global_reload=false;
-  }
+  main_script_engine->start();
 }
 
 
