@@ -2,7 +2,7 @@
 //
 // Dynamic router service for Livewire networks
 //
-//   (C) Copyright 2017 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2018 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,15 +23,12 @@
 
 #include <QList>
 #include <QObject>
-
-#include <sy/synode.h>
+#include <QTimer>
 
 #include "drouter.h"
-#include "protocol.h"
-#include "scripthost.h"
+#include "scriptengine.h"
 
-#define DROUTERD_SCRIPTS_DIRECTORY QString("/etc/drouter.d/scripts")
-#define DROUTERD_SCRIPTS_FILTER QString("*.py")
+#define DROUTERD_PROTOCOL_START_INTERVAL 30000
 #define DROUTERD_USAGE "[--no-scripts]\n"
 
 class MainObject : public QObject
@@ -41,15 +38,17 @@ class MainObject : public QObject
   MainObject(QObject *parent=0);
 
  private slots:
+  void protocolData();
   void scriptsData();
-  void signalData();
 
  private:
-  QList<Protocol *> main_protocols;
-  QList<ScriptHost *> main_scripts;
   DRouter *main_drouter;
-  QTimer *main_script_timer;
-  QTimer *main_signal_timer;
+  QTimer *main_protocol_timer;
+  QList<pid_t> main_protocol_pids;
+  int main_protocol_socks[2];
+  bool main_no_scripts;
+  QTimer *main_scripts_timer;
+  ScriptEngine *main_script_engine;
 };
 
 
